Base
----

Provides the most basic view into the model. This view will
simply apply the model to the provided data and return the
``model-output`` along with the ``model-output``

.. automodule:: gordo.server.views.base
    :members:
    :undoc-members:
    :show-inheritance:
